aboutsummaryrefslogtreecommitdiff
path: root/include/llvm/Module.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/Module.h')
-rw-r--r--include/llvm/Module.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/llvm/Module.h b/include/llvm/Module.h
index 60032474ca..92f137eb95 100644
--- a/include/llvm/Module.h
+++ b/include/llvm/Module.h
@@ -17,8 +17,8 @@
#include "llvm/ValueHolder.h"
class Method;
class GlobalVariable;
-class GlobalValueRefMap; // Used by ConstPoolVals.cpp
-class ConstPoolPointerRef;
+class GlobalValueRefMap; // Used by ConstantVals.cpp
+class ConstantPointerRef;
class Module : public Value, public SymTabValue {
public:
@@ -44,10 +44,10 @@ private:
GlobalValueRefMap *GVRefMap;
// Accessor for the underlying GlobalValRefMap... only through the
- // ConstPoolPointerRef class...
- friend class ConstPoolPointerRef;
- void mutateConstPoolPointerRef(GlobalValue *OldGV, GlobalValue *NewGV);
- ConstPoolPointerRef *getConstPoolPointerRef(GlobalValue *GV);
+ // ConstantPointerRef class...
+ friend class ConstantPointerRef;
+ void mutateConstantPointerRef(GlobalValue *OldGV, GlobalValue *NewGV);
+ ConstantPointerRef *getConstantPointerRef(GlobalValue *GV);
public:
Module();